.. option:: --version

    Print the version of Salt that is running.

.. option:: --versions-report

    Show program's dependencies and version number, and then exit

.. option:: -h, --help

    Show the help message and exit

.. option:: -c CONFIG_DIR, --config-dir=CONFIG_dir

    The location of the Salt configuration directory. This directory contains
    the configuration files for Salt master and minions. The default location
    on most systems is ``/etc/salt``.